@@ -6,7 +6,7 @@ from mopidy import ext, config
 from mopidy.exceptions import ExtensionError
 
 
-__version__ = '1.0.18'
+__version__ = '1.2.5'
 __url__ = 'https://github.com/mopidy/mopidy-soundcloud'
 
 
@@ -22,25 +22,21 @@ class SoundCloudExtension(ext.Extension):
 
     def get_config_schema(self):
         schema = super(SoundCloudExtension, self).get_config_schema()
-        schema['explore'] = config.List()
-        schema['explore_pages'] = config.Integer()
+        schema['explore_songs'] = config.Integer()
         schema['auth_token'] = config.Secret()
+        schema['explore'] = config.Deprecated()
+        schema['explore_pages'] = config.Deprecated()
         return schema
 
     def validate_config(self, config):
         if not config.getboolean('soundcloud', 'enabled'):
             return
         if not config.get('soundcloud', 'auth_token'):
-            raise ExtensionError("In order to use SoundCloud extension you\
-             must provide auth_token, for more information referrer to \
-             https://github.com/mopidy/mopidy-soundcloud/")
+            raise ExtensionError(
+                'In order to use SoundCloud extension you must provide an '
+                'auth token. For more information referrer to '
+                'https://github.com/mopidy/mopidy-soundcloud/')
 
-    def validate_environment(self):
-        try:
-            import requests  # noqa
-        except ImportError as e:
-            raise ExtensionError('Library requests not found', e)
-
-    def get_backend_classes(self):
+    def setup(self, registry):
         from .actor import SoundCloudBackend
-        return [SoundCloudBackend]
+        registry.add('backend', SoundCloudBackend)
