@@ -3,31 +3,29 @@ from __future__ import unicode_literals
 import logging
 import pykka
 
-from mopidy.backends import base
+from mopidy import backend
 
 from .library import SoundCloudLibraryProvider
-from .playlists import SoundCloudPlaylistsProvider
 from .soundcloud import SoundCloudClient
 
 logger = logging.getLogger(__name__)
 
 
-class SoundCloudBackend(pykka.ThreadingActor, base.Backend):
+class SoundCloudBackend(pykka.ThreadingActor, backend.Backend):
 
     def __init__(self, config, audio):
         super(SoundCloudBackend, self).__init__()
         self.config = config
-        self.sc_api = SoundCloudClient(config['soundcloud']['auth_token'])
+        self.remote = SoundCloudClient(config['soundcloud'])
         self.library = SoundCloudLibraryProvider(backend=self)
         self.playback = SoundCloudPlaybackProvider(audio=audio, backend=self)
-        self.playlists = SoundCloudPlaylistsProvider(backend=self)
 
-        self.uri_schemes = ['soundcloud']
+        self.uri_schemes = ['soundcloud', 'sc']
 
 
-class SoundCloudPlaybackProvider(base.BasePlaybackProvider):
+class SoundCloudPlaybackProvider(backend.PlaybackProvider):
 
     def play(self, track):
-        id = self.backend.sc_api.parse_track_uri(track)
-        track = self.backend.sc_api.get_track(id, True)
+        track_id = self.backend.remote.parse_track_uri(track)
+        track = self.backend.remote.get_track(track_id, True)
         return super(SoundCloudPlaybackProvider, self).play(track)
